@@ -29,9 +29,9 @@ opt_group = cfg.OptGroup(name='vmware',
                          title='Options for VMware')
 
 OPTS = [
-    cfg.StrOpt('host_ip',
-               default='',
-               help='IP address of the VMware vSphere host.'),
+    cfg.HostAddressOpt('host_ip',
+                       default='127.0.0.1',
+                       help='IP address of the VMware vSphere host.'),
     cfg.PortOpt('host_port',
                 default=443,
                 help='Port of the VMware vSphere host.'),
@@ -110,25 +110,11 @@ class VsphereInspector(virt_inspector.Inspector):
                                                     'runtime.powerState')
         if vm_powerState == "poweredOff":
             raise virt_inspector.InstanceShutOffException(
-                _('VM %s is poweroff in VMware vSphere') % instance.id)
+                _('VM %s is poweredOff in VMware vSphere') % instance.id)
 
         return vm_mobj
 
-    def inspect_cpu_util(self, instance, duration=None):
-        vm_mobj = self._get_vm_mobj_not_power_off_or_raise(instance)
-        cpu_util_counter_id = self._ops.get_perf_counter_id(
-            VC_AVERAGE_CPU_CONSUMED_CNTR)
-        cpu_util = self._ops.query_vm_aggregate_stats(
-            vm_mobj, cpu_util_counter_id, duration)
-
-        # For this counter vSphere returns values scaled-up by 100, since the
-        # corresponding API can't return decimals, but only longs.
-        # For e.g. if the utilization is 12.34%, the value returned is 1234.
-        # Hence, dividing by 100.
-        cpu_util = cpu_util / 100
-        return virt_inspector.CPUUtilStats(util=cpu_util)
-
-    def inspect_vnic_rates(self, instance, duration=None):
+    def inspect_vnic_rates(self, instance, duration):
         vm_mobj = self._get_vm_mobj_not_power_off_or_raise(instance)
 
         vnic_stats = {}
@@ -149,32 +135,20 @@ class VsphereInspector(virt_inspector.Inspector):
             vnic_ids.update(six.iterkeys(vnic_id_to_stats_map))
 
         # Stats provided from vSphere are in KB/s, converting it to B/s.
-        for vnic_id in vnic_ids:
+        for vnic_id in sorted(vnic_ids):
             rx_bytes_rate = (vnic_stats[VC_NETWORK_RX_COUNTER]
                              .get(vnic_id, 0) * units.Ki)
             tx_bytes_rate = (vnic_stats[VC_NETWORK_TX_COUNTER]
                              .get(vnic_id, 0) * units.Ki)
-
-            stats = virt_inspector.InterfaceRateStats(rx_bytes_rate,
-                                                      tx_bytes_rate)
-            interface = virt_inspector.Interface(
+            yield virt_inspector.InterfaceRateStats(
                 name=vnic_id,
                 mac=None,
                 fref=None,
-                parameters=None)
-            yield (interface, stats)
+                parameters=None,
+                rx_bytes_rate=rx_bytes_rate,
+                tx_bytes_rate=tx_bytes_rate)
 
-    def inspect_memory_usage(self, instance, duration=None):
-        vm_mobj = self._get_vm_mobj_not_power_off_or_raise(instance)
-        mem_counter_id = self._ops.get_perf_counter_id(
-            VC_AVERAGE_MEMORY_CONSUMED_CNTR)
-        memory = self._ops.query_vm_aggregate_stats(
-            vm_mobj, mem_counter_id, duration)
-        # Stat provided from vSphere is in KB, converting it to MB.
-        memory = memory / units.Ki
-        return virt_inspector.MemoryUsageStats(usage=memory)
-
-    def inspect_disk_rates(self, instance, duration=None):
+    def inspect_disk_rates(self, instance, duration):
         vm_mobj = self._get_vm_mobj_not_power_off_or_raise(instance)
 
         disk_stats = {}
@@ -198,12 +172,34 @@ class VsphereInspector(virt_inspector.Inspector):
             def stat_val(counter_name):
                 return disk_stats[counter_name].get(disk_id, 0)
 
-            disk = virt_inspector.Disk(device=disk_id)
             # Stats provided from vSphere are in KB/s, converting it to B/s.
-            disk_rate_info = virt_inspector.DiskRateStats(
+            yield virt_inspector.DiskRateStats(
+                device=disk_id,
                 read_bytes_rate=stat_val(VC_DISK_READ_RATE_CNTR) * units.Ki,
                 read_requests_rate=stat_val(VC_DISK_READ_REQUESTS_RATE_CNTR),
                 write_bytes_rate=stat_val(VC_DISK_WRITE_RATE_CNTR) * units.Ki,
                 write_requests_rate=stat_val(VC_DISK_WRITE_REQUESTS_RATE_CNTR)
             )
-            yield(disk, disk_rate_info)
+
+    def inspect_instance(self, instance, duration):
+        vm_mobj = self._get_vm_mobj_not_power_off_or_raise(instance)
+        cpu_util_counter_id = self._ops.get_perf_counter_id(
+            VC_AVERAGE_CPU_CONSUMED_CNTR)
+        cpu_util = self._ops.query_vm_aggregate_stats(
+            vm_mobj, cpu_util_counter_id, duration)
+
+        # For this counter vSphere returns values scaled-up by 100, since the
+        # corresponding API can't return decimals, but only longs.
+        # For e.g. if the utilization is 12.34%, the value returned is 1234.
+        # Hence, dividing by 100.
+        cpu_util = cpu_util / 100
+
+        mem_counter_id = self._ops.get_perf_counter_id(
+            VC_AVERAGE_MEMORY_CONSUMED_CNTR)
+        memory = self._ops.query_vm_aggregate_stats(
+            vm_mobj, mem_counter_id, duration)
+        # Stat provided from vSphere is in KB, converting it to MB.
+        memory = memory / units.Ki
+        return virt_inspector.InstanceStats(
+            cpu_util=cpu_util,
+            memory_usage=memory)
