@@ -14,9 +14,7 @@
 
 import abc
 
-from oslo_config import cfg
 from oslo_log import log
-from oslo_utils import timeutils
 import six
 
 from ceilometer.agent import plugin_base
@@ -25,11 +23,6 @@ from ceilometer.ipmi.platform import exception as nmexcept
 from ceilometer.ipmi.platform import intel_node_manager as node_manager
 from ceilometer import sample
 
-CONF = cfg.CONF
-CONF.import_opt('host', 'ceilometer.service')
-CONF.import_opt('polling_retry', 'ceilometer.ipmi.pollsters',
-                group='ipmi')
-
 LOG = log.getLogger(__name__)
 
 
@@ -38,7 +31,7 @@ class _Base(plugin_base.PollsterBase):
 
     def setup_environment(self):
         super(_Base, self).setup_environment()
-        self.nodemanager = node_manager.NodeManager()
+        self.nodemanager = node_manager.NodeManager(self.conf)
         self.polling_failures = 0
 
         # Do not load this extension if no NM support
@@ -66,8 +59,7 @@ class _Base(plugin_base.PollsterBase):
             LOG.warning(_('Polling %(name)s failed for %(cnt)s times!')
                         % ({'name': self.NAME,
                             'cnt': self.polling_failures}))
-            if (CONF.ipmi.polling_retry >= 0 and
-                    self.polling_failures > CONF.ipmi.polling_retry):
+            if 0 <= self.conf.ipmi.polling_retry < self.polling_failures:
                 LOG.warning(_('Pollster for %s is disabled!') % self.NAME)
                 raise plugin_base.PollsterPermanentError(resources)
             else:
@@ -76,7 +68,7 @@ class _Base(plugin_base.PollsterBase):
         self.polling_failures = 0
 
         metadata = {
-            'node': CONF.host
+            'node': self.conf.host
         }
 
         if stats:
@@ -89,8 +81,7 @@ class _Base(plugin_base.PollsterBase):
                 volume=data,
                 user_id=None,
                 project_id=None,
-                resource_id=CONF.host,
-                timestamp=timeutils.utcnow().isoformat(),
+                resource_id=self.conf.host,
                 resource_metadata=metadata)
 
 
