@@ -20,7 +20,6 @@ import requests
 from requests import adapters
 from six.moves.urllib import parse as urlparse
 
-from ceilometer.i18n import _LE
 from ceilometer import publisher
 
 LOG = log.getLogger(__name__)
@@ -35,19 +34,27 @@ class HttpPublisher(publisher.ConfigPublisherBase):
     `timeout` and `max_retries` will be set to 5 and 2 respectively. Additional
     parameters are:
 
-        - ssl can be enabled by setting `verify_ssl`
+        - ssl certificate verification can be disabled by setting `verify_ssl`
+          to False
         - batching can be configured by `batch`
-        - connection pool size configured using `poolsize`
+        - Basic authentication can be configured using the URL authentication
+          scheme: http://username:password@example.com
+        - For certificate authentication, `clientcert` and `clientkey` are the
+          paths to the certificate and key files respectively. `clientkey` is
+          only required if the clientcert file doesn't already contain the key.
+
+    All of the parameters mentioned above get removed during processing,
+    with the remaining portion of the URL being used as the actual endpoint.
+    e.g. https://username:password@example.com/path?verify_ssl=False&q=foo
+    will result in a call to https://example.com/path?q=foo
 
     To use this publisher for samples, add the following section to the
     /etc/ceilometer/pipeline.yaml file or simply add it to an existing
     pipeline::
 
           - name: meter_file
-            interval: 600
-            counters:
+            meters:
                 - "*"
-            transformers:
             publishers:
                 - http://host:80/path?timeout=1&max_retries=2&batch=False
 
@@ -63,7 +70,6 @@ class HttpPublisher(publisher.ConfigPublisherBase):
 
     def __init__(self, conf, parsed_url):
         super(HttpPublisher, self).__init__(conf, parsed_url)
-        self.target = parsed_url.geturl()
 
         if not parsed_url.hostname:
             raise ValueError('The hostname of an endpoint for '
@@ -83,20 +89,49 @@ class HttpPublisher(publisher.ConfigPublisherBase):
         self.poster = (
             self._do_post if strutils.bool_from_string(self._get_param(
                 params, 'batch', True)) else self._individual_post)
+        verify_ssl = self._get_param(params, 'verify_ssl', True)
         try:
-            self.verify_ssl = strutils.bool_from_string(
-                self._get_param(params, 'verify_ssl', None), strict=True)
+            self.verify_ssl = strutils.bool_from_string(verify_ssl,
+                                                        strict=True)
         except ValueError:
-            self.verify_ssl = (self._get_param(params, 'verify_ssl', None)
-                               or True)
+            self.verify_ssl = (verify_ssl or True)
+
+        username = parsed_url.username
+        password = parsed_url.password
+        if username:
+            self.client_auth = (username, password)
+            netloc = parsed_url.netloc.replace(username+':'+password+'@', '')
+        else:
+            self.client_auth = None
+            netloc = parsed_url.netloc
+
+        clientcert = self._get_param(params, 'clientcert', None)
+        clientkey = self._get_param(params, 'clientkey', None)
+        if clientcert:
+            if clientkey:
+                self.client_cert = (clientcert, clientkey)
+            else:
+                self.client_cert = clientcert
+        else:
+            self.client_cert = None
+
         self.raw_only = strutils.bool_from_string(
             self._get_param(params, 'raw_only', False))
 
-        pool_size = self._get_param(params, 'poolsize', 10, int)
         kwargs = {'max_retries': self.max_retries,
-                  'pool_connections': pool_size, 'pool_maxsize': pool_size}
+                  'pool_connections': conf.max_parallel_requests,
+                  'pool_maxsize': conf.max_parallel_requests}
         self.session = requests.Session()
-        # FIXME(gordc): support https in addition to http
+
+        # authentication & config params have been removed, so use URL with
+        # updated query string
+        self.target = urlparse.urlunsplit([
+            parsed_url.scheme,
+            netloc,
+            parsed_url.path,
+            urlparse.urlencode(params),
+            parsed_url.fragment])
+
         self.session.mount(self.target, adapters.HTTPAdapter(**kwargs))
 
         LOG.debug('HttpPublisher for endpoint %s is initialized!' %
@@ -105,8 +140,8 @@ class HttpPublisher(publisher.ConfigPublisherBase):
     @staticmethod
     def _get_param(params, name, default_value, cast=None):
         try:
-            return cast(params.get(name)[-1]) if cast else params.get(name)[-1]
-        except (ValueError, TypeError):
+            return cast(params.pop(name)[-1]) if cast else params.pop(name)[-1]
+        except (ValueError, TypeError, KeyError):
             LOG.debug('Default value %(value)s is used for %(name)s' %
                       {'value': default_value, 'name': name})
             return default_value
@@ -124,13 +159,15 @@ class HttpPublisher(publisher.ConfigPublisherBase):
         try:
             res = self.session.post(self.target, data=data,
                                     headers=self.headers, timeout=self.timeout,
+                                    auth=self.client_auth,
+                                    cert=self.client_cert,
                                     verify=self.verify_ssl)
             res.raise_for_status()
             LOG.debug('Message posting to %s: status code %d.',
                       self.target, res.status_code)
         except requests.exceptions.HTTPError:
-            LOG.exception(_LE('Status Code: %(code)s. '
-                              'Failed to dispatch message: %(data)s') %
+            LOG.exception('Status Code: %(code)s. '
+                          'Failed to dispatch message: %(data)s' %
                           {'code': res.status_code, 'data': data})
 
     def publish_samples(self, samples):
