@@ -133,8 +133,8 @@ class Connection(object):
         'storage': {'production_ready': False},
     }
 
-    def __init__(self, url):
-        pass
+    def __init__(self, conf, url):
+        self.conf = conf
 
     @staticmethod
     def upgrade():
