@@ -35,9 +35,10 @@ class TestListResources(v2.FunctionalTest):
     def _verify_resource_timestamps(self, res, first, last):
         # Bounds need not be tight (see ceilometer bug #1288372)
         self.assertIn('first_sample_timestamp', res)
-        self.assertTrue(first.isoformat() >= res['first_sample_timestamp'])
+        self.assertGreaterEqual(first.isoformat(),
+                                res['first_sample_timestamp'])
         self.assertIn('last_sample_timestamp', res)
-        self.assertTrue(last.isoformat() <= res['last_sample_timestamp'])
+        self.assertLessEqual(last.isoformat(), res['last_sample_timestamp'])
 
     def test_instance_no_metadata(self):
         timestamp = datetime.datetime(2012, 7, 2, 10, 40)
@@ -232,6 +233,32 @@ class TestListResources(v2.FunctionalTest):
         sources = [r['source'] for r in data]
         self.assertEqual(['test_list_resources'], sources)
 
+    def test_resource_id_with_slash(self):
+        s = sample.Sample(
+            'storage.containers.objects',
+            'gauge',
+            '',
+            1,
+            '19fbed01c21f4912901057021b9e7111',
+            '45acc90399134206b3b41f3d3a0a06d6',
+            '29f809d9-88bb-4c40-b1ba-a77a1fcf8ceb/glance',
+            timestamp=datetime.datetime(2012, 7, 2, 10, 40).isoformat(),
+            resource_metadata={},
+            source='test_show_special_resource',
+        )
+
+        msg = utils.meter_message_from_counter(
+            s, self.CONF.publisher.telemetry_secret,
+        )
+        msg['timestamp'] = datetime.datetime(2012, 7, 2, 10, 40)
+        self.conn.record_metering_data(msg)
+
+        rid_encoded = '29f809d9-88bb-4c40-b1ba-a77a1fcf8ceb%252Fglance'
+        resp = self.get_json('/resources/%s' % rid_encoded)
+        self.assertEqual("19fbed01c21f4912901057021b9e7111", resp["user_id"])
+        self.assertEqual('29f809d9-88bb-4c40-b1ba-a77a1fcf8ceb/glance',
+                         resp["resource_id"])
+
     def test_with_invalid_resource_id(self):
         sample1 = sample.Sample(
             'instance',
@@ -482,12 +509,12 @@ class TestListResources(v2.FunctionalTest):
         links = data[0]['links']
         self.assertEqual(2, len(links))
         self.assertEqual('self', links[0]['rel'])
-        self.assertTrue((self.PATH_PREFIX + '/resources/resource-id')
-                        in links[0]['href'])
+        self.assertIn((self.PATH_PREFIX + '/resources/resource-id'),
+                      links[0]['href'])
         self.assertEqual('instance', links[1]['rel'])
-        self.assertTrue((self.PATH_PREFIX + '/meters/instance?'
-                         'q.field=resource_id&q.value=resource-id')
-                        in links[1]['href'])
+        self.assertIn((self.PATH_PREFIX + '/meters/instance?'
+                      'q.field=resource_id&q.value=resource-id'),
+                      links[1]['href'])
 
     def test_resource_skip_meter_links(self):
         sample1 = sample.Sample(
@@ -513,8 +540,8 @@ class TestListResources(v2.FunctionalTest):
         links = data[0]['links']
         self.assertEqual(len(links), 1)
         self.assertEqual(links[0]['rel'], 'self')
-        self.assertTrue((self.PATH_PREFIX + '/resources/resource-id')
-                        in links[0]['href'])
+        self.assertIn((self.PATH_PREFIX + '/resources/resource-id'),
+                      links[0]['href'])
 
 
 class TestListResourcesRestriction(v2.FunctionalTest):
