@@ -16,6 +16,7 @@
 import os
 import uuid
 
+import fixtures
 from gnocchiclient import exceptions as gnocchi_exc
 from keystoneauth1 import exceptions as ka_exceptions
 import mock
@@ -23,7 +24,6 @@ from oslo_config import fixture as config_fixture
 from oslo_utils import fileutils
 from oslo_utils import fixture as utils_fixture
 from oslo_utils import timeutils
-from oslotest import mockpatch
 import requests
 import six
 from stevedore import extension
@@ -307,7 +307,6 @@ FLOATINGIP_DELETE_END = {
 }
 
 
-@mock.patch('gnocchiclient.v1.client.Client', mock.Mock())
 class DispatcherTest(base.BaseTestCase):
 
     def setUp(self):
@@ -361,7 +360,7 @@ class DispatcherTest(base.BaseTestCase):
         ks_client = mock.Mock(auth_token='fake_token')
         ks_client.projects.find.return_value = mock.Mock(
             name='gnocchi', id='a2d42c23-d518-46b6-96ab-3fba2e146859')
-        self.useFixture(mockpatch.Patch(
+        self.useFixture(fixtures.MockPatch(
             'ceilometer.keystone_client.get_client',
             return_value=ks_client))
         self.ks_client = ks_client
@@ -530,6 +529,7 @@ class DispatcherWorkflowTest(base.BaseTestCase,
             metric_names=[
                 'disk.root.size', 'disk.ephemeral.size',
                 'memory', 'vcpus', 'memory.usage', 'memory.resident',
+                'memory.swap.in', 'memory.swap.out',
                 'memory.bandwidth.total', 'memory.bandwidth.local',
                 'cpu', 'cpu.delta', 'cpu_util', 'vcpus', 'disk.read.requests',
                 'cpu_l3_cache', 'perf.cpu.cycles', 'perf.instructions',
@@ -614,7 +614,7 @@ class DispatcherWorkflowTest(base.BaseTestCase,
         ks_client = mock.Mock()
         ks_client.projects.find.return_value = mock.Mock(
             name='gnocchi', id='a2d42c23-d518-46b6-96ab-3fba2e146859')
-        self.useFixture(mockpatch.Patch(
+        self.useFixture(fixtures.MockPatch(
             'ceilometer.keystone_client.get_client',
             return_value=ks_client))
         self.ks_client = ks_client
@@ -652,7 +652,6 @@ class DispatcherWorkflowTest(base.BaseTestCase,
         self.useFixture(utils_fixture.TimeFixture(now))
 
         expected_calls = [
-            mock.call.capabilities.list(),
             mock.call.resource.search('instance_disk', search_params),
             mock.call.resource.search('instance_network_interface',
                                       search_params),
@@ -682,7 +681,7 @@ class DispatcherWorkflowTest(base.BaseTestCase,
                                       IMAGE_DELETE_START,
                                       VOLUME_DELETE_START,
                                       FLOATINGIP_DELETE_END])
-        self.assertEqual(9, len(fakeclient.mock_calls))
+        self.assertEqual(8, len(fakeclient.mock_calls))
         for call in expected_calls:
             self.assertIn(call, fakeclient.mock_calls)
 
@@ -698,7 +697,6 @@ class DispatcherWorkflowTest(base.BaseTestCase,
         gnocchi_id = uuid.uuid4()
 
         expected_calls = [
-            mock.call.capabilities.list(),
             mock.call.metric.batch_resources_metrics_measures(
                 {resource_id: {metric_name: self.measures_attributes}},
                 create_metrics=True)
