@@ -20,13 +20,13 @@ import socket
 
 import mock
 import msgpack
-from oslo_config import fixture as fixture_config
 from oslo_utils import netutils
 from oslotest import base
 
 from ceilometer.publisher import udp
 from ceilometer.publisher import utils
 from ceilometer import sample
+from ceilometer import service
 
 
 COUNTER_SOURCE = 'testsource'
@@ -110,7 +110,7 @@ class TestUDPPublisher(base.BaseTestCase):
 
     def setUp(self):
         super(TestUDPPublisher, self).setUp()
-        self.CONF = self.useFixture(fixture_config.Config()).conf
+        self.CONF = service.prepare_service([], [])
         self.CONF.publisher.telemetry_secret = 'not-so-secret'
 
     def _check_udp_socket(self, url, expected_addr_family):
