@@ -15,17 +15,16 @@ import datetime
 import traceback
 import uuid
 
+import fixtures
 import mock
-from oslo_config import fixture as fixture_config
 import oslo_messaging
-from oslotest import mockpatch
 
 from ceilometer.event.storage import models
 from ceilometer import pipeline
 from ceilometer import publisher
 from ceilometer.publisher import test as test_publisher
 from ceilometer.publisher import utils
-
+from ceilometer import service
 from ceilometer.tests import base
 
 
@@ -46,8 +45,7 @@ class EventPipelineTestCase(base.BaseTestCase):
 
     def setUp(self):
         super(EventPipelineTestCase, self).setUp()
-        self.CONF = self.useFixture(fixture_config.Config()).conf
-        self.CONF([])
+        self.CONF = service.prepare_service([], [])
 
         self.p_type = pipeline.EVENT_TYPE
         self.transformer_manager = None
@@ -78,13 +76,13 @@ class EventPipelineTestCase(base.BaseTestCase):
             raw={'status': 'stopped'}
         )
 
-        self.useFixture(mockpatch.PatchObject(
+        self.useFixture(fixtures.MockPatchObject(
             publisher, 'get_publisher', side_effect=self.get_publisher))
 
         self._setup_pipeline_cfg()
 
         self._reraise_exception = True
-        self.useFixture(mockpatch.Patch(
+        self.useFixture(fixtures.MockPatch(
             'ceilometer.pipeline.LOG.exception',
             side_effect=self._handle_reraise_exception))
 
@@ -424,7 +422,7 @@ class EventPipelineTestCase(base.BaseTestCase):
         test_data['message_signature'] = message_sign
 
         fake_publisher = mock.Mock()
-        self.useFixture(mockpatch.Patch(
+        self.useFixture(fixtures.MockPatch(
             'ceilometer.publisher.test.TestPublisher',
             return_value=fake_publisher))
 
